@@ -1,5 +1,5 @@
 package Geo::Coder::OpenCage;
-$Geo::Coder::OpenCage::VERSION = '0.07';
+$Geo::Coder::OpenCage::VERSION = '0.08';
 use strict;
 use warnings;
 
@@ -21,21 +21,22 @@ sub new {
         api_key => $params{api_key},
         ua      => HTTP::Tiny->new(agent => "Geo::Coder::OpenCage"),
         json    => JSON->new()->utf8(),
-        url     => URI->new('http://api.opencagedata.com/geocode/v1/json/'),
+        url     => URI->new('https://api.opencagedata.com/geocode/v1/json/'),
     };
-
     return bless $self, $class;
 }
 
 
 my @valid_params = qw(
     add_request
+    bounds
     countrycode
     language
     limit
     min_confidence
     no_annotations
     no_dedupe
+    no_record
     q
 );
 sub geocode {
@@ -115,7 +116,7 @@ Geo::Coder::OpenCage
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
